import type { AccountId } from "../models/AccountId";
import type { EmailAddress } from "../models/EmailAddress";
import type { SubscriptionPlan } from "../models/SubscriptionPlan";
import type { UserAccountListItem } from "../models/UserAccountListItem";
import type { UserId } from "../models/UserId";
export declare class AdminService {
    /**
     * Looks up information for a user by their email address.
     * @param email
     * @returns UserAccountListItem Success.
     * @throws ApiError
     */
    static lookupEmailAddress(email: EmailAddress): Promise<Array<UserAccountListItem>>;
    /**
     * Looks up information for a user by their user ID.
     * @param userId
     * @returns UserAccountListItem Success.
     * @throws ApiError
     */
    static lookupUserId(userId: UserId): Promise<Array<UserAccountListItem>>;
    /**
     * Looks up information for an account by its account ID.
     * @param accountId
     * @returns UserAccountListItem Success.
     * @throws ApiError
     */
    static lookupAccountId(accountId: AccountId): Promise<UserAccountListItem>;
    /**
     * Disables the user's access, deletes their files, and purges the CDN.
     * @param accountId
     * @returns void
     * @throws ApiError
     */
    static purgeAccount(accountId: AccountId): Promise<void>;
    /**
     * Set account limits.
     * @param accountId
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static setAccountLimits(accountId: AccountId, requestBody: SubscriptionPlan): Promise<any>;
}
