import type { AccountId } from "../models/AccountId";
import type { Jwt } from "../models/Jwt";
import type { SwitchPlan } from "../models/SwitchPlan";
export declare class BillingService {
    /**
     * Generates the passthrough parameters to be used during checkout. Passthrough parameters are passed back to the
     * browser, which then passes them onto the billing gateway, which in turn passes them back to us via a webhook.
     * Therefore, the parameters need to be signed to prevent the user from modifying them in between.
     * @param accountId
     * @returns Jwt Success.
     * @throws ApiError
     */
    static generateSubscriptionPassthroughToken(accountId: AccountId): Promise<Jwt>;
    /**
     * Called after the user's first checkout to indicate they got as far as completing the payment. Since this endpoint
     * can be called by malicious users without providing payment, the flag we store is never used to authenticate certain
     * actions that require payment details being set: it's merely used to provide an improved experience for
     * non-malicious users -- we use the flag to display a "we're creating your account" loading screen on the dashboard,
     * instead of redirecting the user to a payment details capture screen.
     * @param accountId
     * @returns any Success.
     * @throws ApiError
     */
    static markPaymentDetailsAsSubmitted(accountId: AccountId): Promise<any>;
    /**
     * Deletes the user's subscription (i.e. payment details and tier) but not their account.
     * @param accountId
     * @returns any Success.
     * @throws ApiError
     */
    static cancelSubscription(accountId: AccountId): Promise<any>;
    /**
     * Switches the account onto a different plan.
     * @param accountId
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static switchPlan(accountId: AccountId, requestBody: SwitchPlan): Promise<any>;
}
