import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFileBatchRequestV2 } from "../models/DeleteFileBatchRequestV2";
import type { FileDetails } from "../models/FileDetails";
import type { FilePath } from "../models/FilePath";
export declare class FileV2Service {
    /**
     * Retrieves the full details for a file.
     * @param accountId
     * @param filePath
     * @returns FileDetails Success.
     * @throws ApiError
     */
    static getFileDetails(accountId: AccountId, filePath: FilePath): Promise<FileDetails>;
    /**
     * Synchronously deletes a single file.
     * @param accountId
     * @param filePath
     * @returns void
     * @throws ApiError
     */
    static deleteFile(accountId: AccountId, filePath: FilePath): Promise<void>;
    /**
     * Asynchronously deletes multiple files.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFileBatch(accountId: AccountId, requestBody: DeleteFileBatchRequestV2): Promise<AsyncResponse>;
}
