import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFolderBatchRequest } from "../models/DeleteFolderBatchRequest";
import type { DeleteFolderRequest } from "../models/DeleteFolderRequest";
import type { FolderDetails } from "../models/FolderDetails";
import type { FolderPath } from "../models/FolderPath";
import type { ListFolderChildrenCursor } from "../models/ListFolderChildrenCursor";
import type { ListFolderChildrenLimit } from "../models/ListFolderChildrenLimit";
import type { ListFolderChildrenResponse } from "../models/ListFolderChildrenResponse";
import type { PutFolderRequest } from "../models/PutFolderRequest";
export declare class FolderService {
    /**
     * Creates or updates the folder specified by the `folderPath`.
     *
     * If the folder's ancestors do not exist, they will be created automatically (with empty FolderSettings).
     *
     * Note: you don't need to create folders before uploading files to them.
     * @param accountId
     * @param requestBody
     * @returns FolderDetails Success.
     * @throws ApiError
     */
    static putFolder(accountId: AccountId, requestBody: PutFolderRequest): Promise<FolderDetails>;
    /**
     * Gets the settings for this folder.
     *
     * Returns an empty object if none exist.
     * @param accountId
     * @param folderPath
     * @returns FolderDetails Success.
     * @throws ApiError
     */
    static getFolderDetails(accountId: AccountId, folderPath: FolderPath): Promise<FolderDetails>;
    /**
     * Asynchronously deletes a folder.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolder(accountId: AccountId, requestBody: DeleteFolderRequest): Promise<AsyncResponse>;
    /**
     * Lists the children (files and sub-folders) of a folder.
     *
     * Pagination is complete when the response `cursor` matches the request `cursor`.
     * @param accountId
     * @param folderPath
     * @param cursor
     * @param includeFiles
     * @param includeFolders
     * @param limit
     * @param traverseVirtualFolders
     * @returns ListFolderChildrenResponse Success.
     * @throws ApiError
     */
    static listFolderChildren(accountId: AccountId, folderPath: FolderPath, cursor?: ListFolderChildrenCursor, includeFiles?: boolean, includeFolders?: boolean, limit?: ListFolderChildrenLimit, traverseVirtualFolders?: boolean): Promise<ListFolderChildrenResponse>;
    /**
     * Asynchronously deletes multiple folders.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFolderBatch(accountId: AccountId, requestBody: DeleteFolderBatchRequest): Promise<AsyncResponse>;
}
