import type { AccountId } from "../models/AccountId";
import type { AccountJobId } from "../models/AccountJobId";
import type { AccountJobType } from "../models/AccountJobType";
import type { JobSummary } from "../models/JobSummary";
import type { ListRecentJobsResponse } from "../models/ListRecentJobsResponse";
export declare class JobService {
    /**
     * Gets information on a job (e.g. a batch file deletion).
     *
     * Requires a `secret_*` API key.
     * @param accountId
     * @param jobId
     * @param jobType
     * @returns JobSummary Success.
     * @throws ApiError
     */
    static getJob(accountId: AccountId, jobId: AccountJobId, jobType: AccountJobType): Promise<JobSummary>;
    /**
     * Cancels an in-progress job.
     *
     * Requires a `secret_*` API key.
     * @param accountId
     * @param jobId
     * @param jobType
     * @returns void
     * @throws ApiError
     */
    static cancelJob(accountId: AccountId, jobId: AccountJobId, jobType: AccountJobType): Promise<void>;
    /**
     * Lists the most recently issued jobs (e.g. batch file deletions, folder deletions, etc.).
     *
     * Requires a `secret_*` API key.
     * @param accountId
     * @param jobType
     * @returns ListRecentJobsResponse Success.
     * @throws ApiError
     */
    static listRecentJobs(accountId: AccountId, jobType: Array<AccountJobType>): Promise<ListRecentJobsResponse>;
}
