/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { DeleteFolderBatchRequest } from "../models/DeleteFolderBatchRequest";
import type { DeleteFolderRequest } from "../models/DeleteFolderRequest";
import type { FolderDetails } from "../models/FolderDetails";
import type { FolderPath } from "../models/FolderPath";
import type { ListFolderChildrenCursor } from "../models/ListFolderChildrenCursor";
import type { ListFolderChildrenLimit } from "../models/ListFolderChildrenLimit";
import type { ListFolderChildrenResponse } from "../models/ListFolderChildrenResponse";
import type { PutFolderRequest } from "../models/PutFolderRequest";
import { request as __request } from "../core/request";

export class FolderService {
  /**
   * Creates or updates the folder specified by the `folderPath`.
   *
   * If the folder's ancestors do not exist, they will be created automatically (with empty FolderSettings).
   *
   * Note: you don't need to create folders before uploading files to them.
   * @param accountId
   * @param requestBody
   * @returns FolderDetails Success.
   * @throws ApiError
   */
  public static async putFolder(accountId: AccountId, requestBody: PutFolderRequest): Promise<FolderDetails> {
    const result = await __request({
      method: "PUT",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Gets the settings for this folder.
   *
   * Returns an empty object if none exist.
   * @param accountId
   * @param folderPath
   * @returns FolderDetails Success.
   * @throws ApiError
   */
  public static async getFolderDetails(accountId: AccountId, folderPath: FolderPath): Promise<FolderDetails> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders`,
      query: {
        folderPath: folderPath
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes a folder.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolder(accountId: AccountId, requestBody: DeleteFolderRequest): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the children (files and sub-folders) of a folder.
   *
   * Pagination is complete when the response `cursor` matches the request `cursor`.
   * @param accountId
   * @param folderPath
   * @param cursor
   * @param includeFiles
   * @param includeFolders
   * @param limit
   * @param traverseVirtualFolders
   * @returns ListFolderChildrenResponse Success.
   * @throws ApiError
   */
  public static async listFolderChildren(
    accountId: AccountId,
    folderPath: FolderPath,
    cursor?: ListFolderChildrenCursor,
    includeFiles?: boolean,
    includeFolders?: boolean,
    limit?: ListFolderChildrenLimit,
    traverseVirtualFolders?: boolean
  ): Promise<ListFolderChildrenResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders/children`,
      query: {
        folderPath: folderPath,
        cursor: cursor,
        includeFiles: includeFiles,
        includeFolders: includeFolders,
        limit: limit,
        traverseVirtualFolders: traverseVirtualFolders
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes multiple folders.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolderBatch(
    accountId: AccountId,
    requestBody: DeleteFolderBatchRequest
  ): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders/batch`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}
